/*
 * File: StateCodes.js
 * -------------------
 * This program looks up state abbreviations from a map loaded with the
 * postal abbreviations of the 50 U.S. states.
 */

"use strict";

/*
 * Reads state codes from the user and reports the corresponding state name.
 * Entering a blank line terminates the program.
 */

function StateCodes() {
   let callback = function(text) {
      let lines = JSFileChooser.convertToLineArray(text);
      let stateCodes = parseStateCodes(lines);
      requestInputFromUser(stateCodes);
   };
   JSFileChooser.chooseTextFile(callback);
}

/*
 * Reads the specified file and returns a map between keys and values.
 * The format of the data file is a series of lines that look like this:
 *
 *     code=state
 *
 * Once the map has been created, clients can lookup a key by
 * writing stateCodes[code].
 */
function parseStateCodes(lines) {
   let stateCodes = {};
   let line = lines.shift();
   while (line !== undefined) {
      let ep = line.indexOf("=");
      let code = line.substring(0, ep).trim();
      let state = line.substring(ep + 1).trim();
      stateCodes[code] = state;
      line = lines.shift();
   }
   return stateCodes;
}

/**
 * Repeatedly prompts the user for state codes, printing
 * the corresponding state for each one.  The function returns
 * when the user types in the empty string.
 */
function requestInputFromUser(stateCodes) {
   // placeholder to be filled in by you
}
